@@ -6,7 +6,7 @@ import pandas
 from hts.hierarchy import HierarchyTree
 from hts._t import Model
 from hts.model.base import TimeSeriesModel
-from hts.utils import suppress_stdout_stderr
+from hts.utilities.utils import suppress_stdout_stderr
 
 logger = logging.getLogger(__name__)
 
@@ -14,13 +14,39 @@ logger = logging.getLogger(__name__)
 try:
     from fbprophet import Prophet
 except ImportError:  # pragma: no cover
-    logger.error('Mapping requires folium==0.10.0 to be installed, geo mapping will not work')
+    logger.error('prophet model requires fbprophet to work, install it with:\npip install scikit-hts[prophet]')
 
 
 logging.getLogger('fbprophet').setLevel(logging.ERROR)
 
 
 class FBProphetModel(TimeSeriesModel):
+    """
+    Wrapper class around ``fbprophet.Prophet``
+
+    Attributes
+    ----------
+    model : Prophet
+        The instance of the model
+
+    mse : float
+        MSE for in-sample predictions
+
+    residual : numpy.ndarry
+        Residuals for the in-sample predictions
+
+    forecast : pandas.DataFramer
+        The forecast for the trained model
+
+    Methods
+    -------
+    fit(self, **fit_args)
+        Fits underlying models to the data, passes kwargs to ``SARIMAX``
+
+    predict(self, node, steps_ahead: int = 10, freq: str = 'D', **predict_args)
+        Predicts the n-step ahead forecast. Exogenous variables are required if models were
+        fit using them, frequency should be passed as well
+    """
     def __init__(self, node: HierarchyTree, **kwargs):
         super().__init__(Model.prophet.name, node, **kwargs)
         self.cap = None
@@ -66,8 +92,7 @@ class FBProphetModel(TimeSeriesModel):
     def predict(self,
                 node: HierarchyTree,
                 freq: str = 'D',
-                steps_ahead: int = 1,
-                **predict_args):
+                steps_ahead: int = 1):
 
         df = self._reformat(node.item)
         future = self.model.make_future_dataframe(periods=steps_ahead,
